@@ -44,16 +44,16 @@ class AccerciserAboutDialog(gtk.AboutDialog):
   AUTHORS = ['Eitan Isaacson <eitan@ascender.com>',
              'Peter Parente <pparente@us.ibm.com>',
              'Brian Nitz <brian.nitz@oracle.com>',
-             'Javier Hernández <jhernandez@emergya.es>']
+             'Javier Hernández <javi@raisingthefloor.org>']
   ARTISTS = ['Eitan Isaacson <eitan@ascender.com>',
              'James Stipp <James_Stipp@us.ibm.com>',
              'Vincent Geddes <vincent.geddes@gmail.com>']
   DOCUMENTERS = ['Eitan Isaacson <eitan@ascender.com>']
   TRANSLATORS = _('translator-credits')
   COMMENTS = _('An interactive Python accessibility explorer')
-  COPYRIGHT =  _('accerciser Copyright (c) 2006, 2007 IBM Corporation (BSD)')
+  COPYRIGHT =  _('accerciser Copyright © 2006, 2007 IBM Corporation (BSD)')
   LICENSE = \
-      _('The New BSD License See the COPYING and NOTICE files for details.')
+      _('The New BSD License. See the COPYING and NOTICE files for details.')
   WEB_URL = 'http://live.gnome.org/Accerciser'
   WEB_LABEL = _('Web site')
   def __init__(self):
